#
# spec file for package pueue
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

Name:           pueue
Version:        3.4.1
Release:        1.5
Summary:        Command-line task management tool for sequential and parallel execution
License:        MIT
URL:            https://github.com/Nukesor/pueue
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
# Completions
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  zsh
BuildRequires:  fish

%description
Pueue is a command-line task management tool for sequential and parallel execution of long-running tasks.
It's a tool that processes a queue of shell commands.
Since Pueue is not bound to any terminal, you can control your tasks from any terminal on the same machine.
The queue will be continuously processed, even if you no longer have any active ssh sessions.

%package fish-completion
Summary:        Fish Completion for %{name}
Supplements:    (%{name} and fish)
Requires:       %{name} = %{version}
BuildArch:      noarch

%description fish-completion
The official fish completion script for %{name}.

%package bash-completion
Summary:        Fish Completion for %{name}
Supplements:    (%{name} and bash-completion)
Requires:       %{name} = %{version}
BuildArch:      noarch

%description bash-completion
The official bash completion script for %{name}.

%package zsh-completion
Summary:        Fish Completion for %{name}
Supplements:    (%{name} and zsh)
Requires:       %{name} = %{version}
BuildArch:      noarch

%description zsh-completion
The official zsh completion script for %{name}.

%prep
%autosetup -a1

%build
%{cargo_build}

# Generate completions
for shell in bash fish zsh; do
  ./target/release/pueue completions ${shell} .
done

%check
%{cargo_test}

%install
install -D -m 0755 target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -D -m 0755 target/release/%{name}d %{buildroot}%{_bindir}/%{name}d

#Install shell completion
install -Dm 0644 %{name}.bash %{buildroot}/%{_datadir}/bash-completion/completions/%{name}
install -Dm 0644 %{name}.fish %{buildroot}/%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -Dm 0644 _%{name} %{buildroot}/%{_datadir}/zsh/site-functions/_%{name}

# Install user service
install -Dm644 utils/%{name}d.service %{buildroot}%{_userunitdir}/%{name}d.service

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/%{name}
%{_bindir}/%{name}d
%{_userunitdir}/%{name}d.service

%files bash-completion
%{_datadir}/bash-completion

%files fish-completion
%{_datadir}/fish

%files zsh-completion
%{_datadir}/zsh

%changelog
* Sun Jun  9 2024 Joshua Smith <smolsheep@opensuse.org>
- Correct Supplements from bash to bash-completion
* Sat Jun  8 2024 Joshua Smith <smolsheep@opensuse.org>
- Change from obsolete disabledrun to manualrun in _service
- Remove obsoleted cargo_config (now part of vendoring)
- Update to 3.4.1:
  Added
  * Nushell autocompletion script
  * Add FreeBSD process helper to facilitate FreeBSD builds
  Changed
  * Replace chrono-english by the interim drop-in replacement
- Updates from 3.4.0:
  Added
  * Support modification of task priorities via pueue edit
  - -priority/-o and pueue restart --edit-priority/-o
  * If no output directory is provided in completions, the
    generated file is printed to stdout
  * Allow setting the parallel_tasks value of groups to 0. Setting
    this value allows unlimited tasks for that group
  Fixed
  * Include priority in Tasks' Debug output
  * Made the daemon exit gracefully (exit code 0) on SIGINT and
    SIGTEM.
  * Fix reading of configuration files that lacks a shared section
  * Respect the -g flag when using the status filter query
* Sun Jan  7 2024 pousaduarte@gmail.com
- Update to version 3.3.3:
  * docs: Update changelog for release
  * fix: Clippy lints
  * fix: --priority takes multiple args
  * change: Changes for rustls 0.22
  * cargo: Bump ring from 0.16 to 0.17
* Sun Dec  3 2023 pousaduarte@gmail.com
- Update to version 3.3.2:
  * fix: Ignore flaky apple test
  * fix: Default config location of pueue_aliases.yml
  * docs: Add info about slurm to README
  * fix: Temporarily ignore flaky mac-os test
  * Fix typo
  * fix: Panic when calling parallel without arguments
  * fix: Temporarily ignore flaky test for x86 apple platform
  * refactor: Use cfg_attr for conditional compilation
* Sun Nov  5 2023 pousaduarte@gmail.com
- Update to version 3.3.1:
  * docs: Update changelog
  * fix: Daemonization if pueued is not in path
* Sun Oct 22 2023 pousaduarte@gmail.com
- Update to version 3.3.0:
  * docs: Update changelogs
  * fix: race condition in log test for ci
  * add: PUEUE_CONFIG env variable support
  * add: clear an cleanup aliases for clean subcommand
  * fix: Better pid file error messages
  * docs: Update changelog
  * add: daemon env_vars setting
  * add: make shell command configurable
  * remove: Deprecated groups settings field
  * fix: Implement proper Default for settings
  * meta: Use v2 resolver
  * fix: New clippy lints
  * refactor: add_task test helper
  * change: Don't pause groups without queued tasks on kill
  * refactor: Task filter functions
  * add: Parse more signal name variations
  * Feature-completeness
  * fix: Wrong secret timeout
  * add: Justfile
* Sun Jun 18 2023 pousaduarte@gmail.com
- Update to version 3.2.0:
  * docs: Update changelog dates
  * ci: Run coverage action on codecov.yml changes
  * ci: Update codecov ignore rules
  * docs: Update changelog
  * tests: Test new follow behavior and unify output
  * refactor: Parameterize existing follow test
  * change: Improved follow behavior in daemon
  * change: Improved follow behavior in client
  * add: success wait status
  * ci: Only create test coverage for linux
  * ci: Run CI on development PRs
  * docs: Priority changelog entry
  * add: Show priority in status table
  * tests: Task priority
  * add: Respect priority in execution order of tasks
  * add: task.priority field
  * add: helper script to print sha256 sum of release artifacts
  * fix: pueue -h formatting and update README
  * docs: Discourage scripting
  * docs: Remove docs that hint to scripting
  * CHANGELOG.md whitespace
  * Describe filter columns
  * cargo fmt
  * Add CHANGELOG.md entry
  * Add pueue status query documentation
  * docs: Better pueue add help text
  * docs: Format subcommand help texts
  * fix: Lint issues
  * add: Group --json test
  * add: group --json
  * fix: Format
  * docs: Update changelog
  * fix: autocompletion
  * Added pueued.plist
  * fix: Finally unflake worker environment test
  * change: Don't compress windows binaries
  * remove: Manual packaging workflow
  * add: Better issue templates
  * Fix a few typos in CHANGELOG.md
* Sun Mar 26 2023 pousaduarte@gmail.com
- Update to version 3.1.2:
  * docs: append new change log entry
  * fix: flush stdout
  * docs: Proofread
  * update: Use new clapv4 attribute macro syntax
  * docs: Update Changelogs
  * fix: missing newline
  * fix: Flaky test_single_worker
  * docs: Update Changelog
  * Use new libproc functionality to list group pids
  * fix: Remaining clippy issues
  * docs: Update pueue-lib changelog
  * docs: Update Changelog
  * commit: Allow capitalized statuses for wait subcommand
  * refactor: Use std::sync::mpsc instead of crossbeam
  * docs: Proofreading
  * tests: Mark snapshot and template directories as special
  * add: --status to wait subcommand
  * refactor: Client wait code
  * fix: Use custom fork for darwin-libproc version patch
  * fix: clippy issues
  * remove: Unused helper functions
  * refactor: Restructure tests
  * remove: Unncessary lifetimes
  * refactor: Make display code return string & cleanup some code
  * fix: Relative Readme path
  * fix: New clippy lints
  * change: Adjust ARCHITECTURE.md
  * change: Restructure project
  * change: Change client integration testing snapshot approach
  * fix: Bump command-group and other deps
  * fix: Remove explicit nix dependency
  * docs: Update some outdated docs
  * change: Enable thin lto
  * fix: Flaky reset test
  * refactor: Use new let else statement
  * fix: Run CI on all Cargo.toml changes
  * fix: darwin-libproc version for publish
  * docs: Fix changelog wording
  * change: Remove tls 1.2 support
  * dev: Disable procfs default features
  * dev: Disable crossterm default features
  * fix: Chrono deprecation warnings
  * change: Remove children flags from messages
  * Include Mac builds in code coverage
  * Build for M1 chips, not A*
  * Enable daemon and client testing on Mac
  * Canonicalize snapshots with regards to temp paths
  * Deprecate the --children switch
  * Simplify child signalling by using From / Into
  * Give each task a separate process group
  * fix: Use localtime for log output
  * refactor: Streamline docblock position
  * add: Task.created_at and Task.enqueued_at
  * add: status query changelog entry
  * Address warnings issued by new rust release.
  * Avoid forwarding messages to the task handler that won't succeed
  * Fix flaky client::group::default test
  * Fix flaky daemon::group::colored test
  * Make tests::helper::wait::wait_for_group_status actually wait
  * Dev support: add test-log to help debug tests
  * Produce test reports for test runs
  * Use cargo nextest to run tests
  * Refactor: Use From / Into to abstract message sending
  * CI: correct codecov configuration syntax
  * Use async sleep
  * docs: Fix inter-code link in TableBuilder.
  * fix: Flaky client wait test
  * add: Label contains filter and label tests
  * fix: Rust v1.64 lints
  * fix: Smaller enqueue_at interval to prevent CI failures at midnight
  * test: status with multiple groups
  * test: status --group
  * refactor: Streamline status snapshot and test names
  * refactor: Simplify state json printing logic
  * fix: Flaky filter start test
  * test: Filter status
  * tests: Fix running test in query tests
  * refactor: Ignore trailing whitespaces in snapshot tests
  * tests: query first and last tasks
  * test: Query columns
  * refactor: Rename filter to query
  * test: order_by status, filter end, filter start
  * tests: Default filter status
  * tests: pueue status filters
  * refactor: Simplify pest result handling
  * add: limit condition
  * add: Order by in status query
  * add: Status filter
  * add: Label filter
  * refactor: Remove unnecessary expects
  * add: Datetime filters
  * refactor: Introduce QueryResult struct
  * refactor: Restructure query code
  * change: Rename select to columns
  * add: status filter query
  * add: 'select' query statement
  * add: Pest and status query parser
  * refactor: Add TableBuilder
  * fix: Flaky tests with parallel tasks
  * refactor: Use new workspace inheritance feature
  * test: pueue wait
  * refactor: Streamline group snapshot and test names
  * refactor: Streamline log snapshot and test names
  * refactor: Streamline follow snapshot and test names
  * refactor: Make run_client_command non-async
  * docs: Update pueue-lib changelog
  * fix: Test and fix label deletion
  * fix: Clippy issues and wording
  * refactor: Deduplicate task edit logic
  * change: Enable pueue edit to edit multiple properties
  * add: Allow editing label on task restart
  * add: Allow editing a task's label
  * refactor: Refactor edit related code
  * fix: Don't use edit_line_wrapper in restart
  * add: Better snapshot comparison via similar-asserts
  * Show task label in log output
  * fix: flaky worker environment test
  * fix: pueue-lib inter-doc links
  * fix: Test debug message
  * refactor: Make TaskToRestart fields optional
  * change: Custom Debug impl for TaskLogMessage
  * test: Aliasing for restarts
  * test: Aliasing
  * add: Use new shared.alias_file config
  * add: settings.shared.alias_file
  * refactor: Simplify child search logic
  * fix: New clippy issue
  * fix: Inject current test env into daemon test tasks
  * refactor: client 'add' code
  * refactor: Remove obsolete add_message factory
  * refactor: Move shell completion into separate function
  * refactor: Document client code and minor code improvements
  * docs: Add changelog for log hint
  * add: Visual hint users that log output might not be complete
  * add: Flag to indicate whether a log has been fully read
  * fix: Reduce chance of hitting a test failure to midnight
  * fix: Don't output invalid json after version update
  * fix: Outdated comment for pueue log task_id
  * test: pueue restart and its editing logic
  * test: editor crashes while in 'pueue edit'
  * test: pueue edit
  * fix: Interpret $EDITOR as a shell expression
  * refactor: Move process handling code to pueue_lib
  * refactor: Simplify platform specific network modules
  * CI: manual packaging workflow to fix UPX issues
  * CI: Ignore flaky windows process tests
  * Ci: Don't fail fast in packaging workflow
  * CI: Move code coverage to dedicated workflow
* Sun Jul 31 2022 pousaduarte@gmail.com
- Update to version 2.1.0:
  * (cargo-release) version 2.1.0
  * docs: Changelog proofreading
  * change: Hide Task.env and AddMessage.env in debug log
  * change: Better debug logging output
  * refactor: Replace vec![] with Vec::new()
  * refactor: Order Cargo.toml files alphabetically
  * tests: Daemon reset logic
  * tests: Client remote follow with last lines
  * tests: Client tests for 'group'
  * tests: client tests for local 'follow'
  * change: Exit 'pueue follow' on finished task when reading local logs
  * tests: client remote 'follow'
  * change: Exit 'pueue follow' on finished task when reading remote logs
  * add: Message::Close
  * fix: Handle rapid successive messages
  * fix: Rephrase a few comments
  * tests: client 'log'
  * fix: Force comfy-table styling with --color=always in logs
  * tests Client 'status --json'
  * add: Full status table
  * fix: Comment
  * tests: Pueue status output
  * fix: Force comfy-table styling with --color=always
  * tests: Build client output helper
  * change: Directly return tasks in wait test helpers
  * refactor: Move client completions test to client test directory
  * refactor: Move tests from 'unix' to 'daemon'
  * refactor: Move group status wait to wait.rs
  * Add --color command-line switch
  * Move light/dark color detail into OutputStyle
  * Refactor output styling
  * Ignore flaky windows test
  * Ignore flaky windows test
  * fix: Windows test lint error
  * Allow lint on windows to fail
  * Avoid making shared_settings a mutable
  * Update the linting steps label to match the contents
  * Add a cache for linting as well
  * Lint on all platforms and targets
  * Disable fail-fast for the test matrix
  * CI: Add a cache for cargo to speed up actions
  * CI: Exclude git/github infra from codecov
  * CI: make sure the target toolchain is available
  * fix: v1.62 Clippy issues
  * Use style_text to style group header
  * docs: Add codecoverage badge
  * ci: Add code coverage
  * ci: Move lint to separate action
  * docs: Update changelog
  * add: Default impl for State
  * change: State no longer contains Settings
  * remove: v1.0.0 backward compatibility
* Tue Jun  7 2022 pousaduarte@gmail.com
- Update to version 2.0.4:
  * (cargo-release) version 2.0.4
  * update: pueue-lib version
  * (cargo-release) version 0.19.7
  * Add entries to changelog
  * Use correct path when removing PID file during shutdown
  * Fix default config directory path
* Sun Jun  5 2022 pousaduarte@gmail.com
- Update to version 2.0.3:
  * (cargo-release) version 2.0.3
  * update: pueue-lib version
  * (cargo-release) version 0.19.6
  * change: Use dirs for directory discovery
  * Update README.md
  * add gnu parallel
  * docs: Add docs on how the communication works in pueue_lib
  * docs: Explain development flow in Readme
  * docs: Fix the wrong issue link in changelog
* Sun Apr  3 2022 pousaduarte@gmail.com
- Update to version 2.0.2:
  * (cargo-release) version 2.0.2
  * fix: Changelog proofreading
  * change: Allow task ordering for format-status
  * change: PID rework
  * fix: Shell autocompletion file generation
  * test: Add test for shell completion generation
  * add: Better filesystem error handling
  * fix: Pass all options to forked daemon
  * add: Better debug output for v2 migration instructions
* Sun Mar 13 2022 pousaduarte@gmail.com
- Update to version 2.0.1:
  * (cargo-release) version 2.0.1
  * (cargo-release) version 0.19.4
  * docs: Update changelog release dates
  * fix: Missing log output on two critical errors
  * docs: proofread ARCHITECTURE.md
  * remove: Error::FileNotFound
  * docs: Add lib Changelogs
  * change: Replace LogRead and LogWrite error with new IoPathError
  * change: Add text to IoError and add IoPathError
  * test: Ensure isolated environment for spawned tasks
  * Don't inherit environment variables from daemon process
  * docs: Update Miscellaneous Readme section
  * fix: Adjust cli docs for a few subcommands
  * add: Better context for some error messages
  * ci: Remove changelog reader action
* Sun Feb 20 2022 pousaduarte@gmail.com
- Update to version 2.0.0:
  * (cargo-release) version 2.0.0
  * (cargo-release) version 0.19.3
  * docs: Set release dates
  * docs: Update README
  * docs: Fix outdated paths
  * add: Better initial output for wait subcommand
  * docs: Fix pueue-lib changelog versions
  * add: Shell completion value hints
  * change: Adjust to pueue-lib's PathBuf usage
  * change: Strict serialization checks for paths
  * (cargo-release) version 0.19.2
  * docs: Update pueue-lib changelog
  * fix: Config sections can be omitted
  * docs: Readme proofreading and adjustments
  * docs: Update readme for v2
  * fix: Missing pueue -V and authorship
  * docs: Update Changelog
* Wed Feb  2 2022 pousaduarte@gmail.com
- Update to version 2.0.0-beta.1:
  * (cargo-release) version 0.19.1
  * docs: Add pueue-lib changelog for 0.19.1
  * docs: Fix changelog date format
  * fix: pueue-lib test clippy issues
  * docs: Update pueue-lib Changelog
  * tests: Add test for log order in file
  * fix: Zsh completion generation
  * change: Combine stdout and stderr
  * feature: Support both task map and list in format-status
  * change: accept tasks for format-state instead of full state
  * refactor: simplify state display logic
  * feature: format-status for preliminary status filtering
  * fix: panic on 'status -g name' with non-existant group name
  * feature: parallel subcommand without args shows group info
  * A few clippy fixes on Windows
  * meta: Require min v1.58 Rust for pueue-lib
  * feature: Configuration profiles
  * fix: Handle errors when editing tasks
  * change: group subcommand flags behind further subcommands.
  * feature: Better notifications for pausing behavior
  * fix: Clippy issue
  * ops: Add dependabot for Github actions packages
  * feature: Follow XDG spec
  * Add --lines to follow
  * fix: streamline remote and local log behavior
  * tests: Daemon log API
  * change: Use seek_to_last_lines in client
  * change: Improve last lines logic
  * fix: Clippy lints
  * ci: Also test pueue-lib in CI
  * update changelog
  * docs: Fix moved LICENSE, fix pueue-lib http paths
  * refactor: Move pueue-lib back into main repository
  * refactor: Move pueue-lib into subdirectory
  * Add output paths to callback template parameters
  * docs: Reference follow subcommand in log docstring
  * fix: Semver value in deprecation decorator
  * Rename master branch to main
  * add: Deprecation warnings for old config values
  * change: Parse legacy group config for backward compatibility
  * change: Immutable configuration file
  * change: Settings::read_with_defaults behavior
  * change: Move group config into state
  * refactor: Replace build.rs with Cargo's rust-version
  * update: Dependencies
  * fix: Project version
  * change: Remove group configuration from settings
  * fix: clippy issues on windows
  * change: check clippy for tests in CI
  * refactor: Adjust tests to new test structure and fix clippy issues
  * refactor: WIP Restructure test helpers
  * Update clap_generate to 3.0.0-beta.5
  * Remove unused tokio features
  * Upgrade to pueue with tokio and new rustls
  * Bump to Rust 2021 edition
  * Replace async-std with tokio and upgrade to rustls v0.20
  * Bump dependencies
  * Rust edition 2021
  * add support clean by group name (-g/--group flag in the clean command)
  * daemon, message_handler: add new function in the fixtures - get_stub_task_in_group
  * daemon, message_handler: add a new helper for add stub tasks into state
  * daemon, message_handler: extract creating of the clean message result into separate function
  * Fix formatting, fix broken tests, add changelog
  * Fix copy-paste error in test
  * Run CI tests on all v*.*.* branches
  * network, clean message: add group in CleanMessage for selective clean by group name
  * network, message: replace false_default with bool::default in CleanMessage
  * Fix cargo fmt
  * Name `GroupMessage::Add` fields
  * Name `GroupMessage::Add` fields
  * Undo breaking change in cli interface
  * Fix related tests
  * Add option for setting parallel tasks during group creation
  * Add parallel tasks option in Group::Add message
  * Add v0.18.0 state deserialization test
  * Add changelog entry
  * Remove default_parallel_tasks setting
  * Add changelog issue links
  * Call 'status' as default on 'pueue' without args
  * Introduce subcommand aliases
  * (cargo-release) start next development iteration 0.18.2-alpha.0
  * (cargo-release) version 0.18.1
  * Fix clippy issue
  * docs: Fix changelog
  * Fix: Missing default group in settings file
  * tests: Ensure to add default group if not in config
  * docs: Fix docstring for backward compatibility test
  * (cargo-release) start next development iteration 0.18.1-alpha.0
  * (cargo-release) version 0.18.0
  * docs: Prepare 0.18 release
  * docs: More docs for network message variants
  * refactor: Change PartialEq to matches
  * refactor: Use TaskSelection in KillMessage
  * refactor: TaskSelection enum in messages
  * refactor: Make GroupMessage an enum
  * (cargo-release) start next development iteration 0.17.3-alpha.0
  * (cargo-release) version 0.17.2
  * fix: Default for client.restart_in_place
  * Add link to main repo in the README.md
  * (cargo-release) start next development iteration 0.17.2-alpha.0
  * (cargo-release) version 0.17.1
  * fix: Add config defaults for status_[date]time_format
  * (cargo-release) start next development iteration 0.17.1-alpha.0
  * (cargo-release) version 0.17.0
  * docs: Update changelog
  * feat: Add 'restart_in_place' config flag for client
  * change: Remove defaults for backward compatibility
  * (cargo-release) start next development iteration 0.16.1-alpha.0
  * (cargo-release) version 0.16.0
  * docs: Update changelog
  * feature: Add config for status datetime formatting
  * test: Backward compatibility for settings
  * change: Remove complex functions from State
  * fix: clippy and fmt condition in CI
  * docs: Fix changelog date
  * (cargo-release) start next development iteration 0.15.1-alpha.0
  * (cargo-release) version 0.15.0
  * change: Drop backward compatibility to v0.15.0
  * fix: task::failed() had wrong logic
  * Revert "fix: task::failed() had wrong logic"
  * fix: task::failed() had wrong logic
  * refactor: Move enqueue_at into TaskStatus::Stashed
  * change: Introduce generic task filter functions
  * refactor: Put TaskResult into TaskStatus::Done
  * (cargo-release) start next development iteration 0.14.2-alpha.0
  * (cargo-release) version 0.14.1
  * feature: Add PartialEq to everything for better testability
  * (cargo-release) start next development iteration 0.14.1-alpha.0
  * (cargo-release) version 0.14.0
  * feature: Add shutdown type to DaemonShutdown message
  * maintenance: Update dependencies
  * (cargo-release) start next development iteration 0.13.2-alpha.0
  * (cargo-release) version 0.13.1
  * Add State::tasks_of_group_in_statuses
  * (cargo-release) start next development iteration 0.13.1-alpha.0
  * (cargo-release) version 0.13.0
  * Adjust contribution guide link
  * Use pretty_assertions
  * Create test helper function for settings
  * Accept lowercase and number in cli for kill signal
  * Simplify receive logic and add better network error handling
  * Move signal to kill message
  * Update dependencies
  * Add signal message
  * Add tests for message backward compatibility
  * Replace generic anyhow with custom library Error
  * Ensure removed state fields are handled
  * Fix tls socket tests for windows
  * Don't write state all the time
  * Backward compatibility tests for state serialization and changed error handling in State io functions
  * Revisit Settings::read and Settings::new
  * Fix test comments
  * Run tls socket tests on all platforms
  * Test tls socket
  * Test unix sockets and make Shared config paths public
  * Fix socket cleanup for windows
  * Better debug message for failed deserialization
  * Only remove existing logfiles
  * Replace remaining 'expect' by context and Results
  * Return debug log string instead of panicking
  * Remove 'full' flag from LogRequestMessage
  * Support other apple platforms
  * Add callback_log_lines to daemon config
  * Migrate to serde_cbor
  * Function to return uncompressed last lines of task logs
  * Derive next task_id from current task ids
  * Fix cargo clippy warnings
  * Update src/settings.rs
  * Add OS and FS stuff to gitignore
  * Use shellexpand to expand the tilde
  * Test more targets
  * Adjust changelog
  * Add comments
  * clippy adjustments for Rust 1.51
  * Add changelog
  * settings: add support dark_mode in settings
  * Update changelog
  * Switch names for GenericListener and Listener
  * Documentation, refactor and overall cleanup
  * Put pueue-lib in it's own repository
* Sun Jan  9 2022 pousaduarte@gmail.com
- Update to version 1.0.6:
  * Bump version to 1.0.6
  * Allow multiple values for 'after' on add
  * docs: Update pull request template
  * fix: Endless loop if task_log directory disappears
  * docs: Add tests and linting to pr template
  * dos: Update PR template
  * Update docs, workflow and templates
  * (cargo-release) version 1.0.4
  * fix: Panic when switching task with itself.
  * fix: Some links to new main branch
  * ops: rename master to main
  * (cargo-release) start next development iteration 1.0.4-alpha.0
  * (cargo-release) version 1.0.3
  * fix: Clippy issue
  * update: Pueue-lib v0.18.1
  * (cargo-release) start next development iteration 1.0.3-alpha.0
  * (cargo-release) version 1.0.2
  * fix: Load updated configs on daemon restart
  * test: Ensure settings are read on restore
  * feature: Add --working-directory to pueue add
  * (cargo-release) start next development iteration 1.0.2-alpha.0
  * (cargo-release) version 1.0.1
  * docs: Update changelog
  * fix: Pin clap to exact beta version
  * docs: Require --locked parameter on cargo install
  * fix: Incremental wait logic for windows process tests
  * update: Various dependencies
  * update: Clap beta.4
  * docs: Require --locked parameter on cargo install
  * (cargo-release) start next development iteration 1.0.1-alpha.0
  * (cargo-release) version 1.0.0
  * docs: Update and proofread changelog
  * update: Bump ctrlc to 3.2.0
  * update: Replace deprecated tempdir with tempfile
  * update: Comfy-table 4.1
  * fix: Flakiness in worker pool tests
  * fix: Shutting down too fast
  * refactor: Cleanup test code
  * tests: Restarting tasks in-place
  * change: Return failure when no tasks are affected by action
  * tests: Parallelism with multiple groups
  * docs: Better remove test docs
  * refactor: Cleanup test code for stashed tasks
  * tests: Test special task add modes
  * fix: Flaky group tests due to new async group removal logic
  * fix: Remove unnecessary println calls
  * (cargo-release) version 1.0.0-rc.4
  * doc: Update Architecture.md
  * fix: Flaky tests due to new async group handling
  * refactor: Consistent naming conventions
  * fix: Clippy issues
  * tests: Improve group tests
  * feature: Dynamic worker pool creation/removal
  * change: Prevent group removal while it has tasks.
  * refactor: Move group addition/removal to TaskHandler
  * tests: Ensure worker variable injection into task environment
  * tests: Correct worker id re-usage
  * tests: Single worker variables
  * feature: Implement datastructure for worker pools
  * change: Only show exitcode on failure
  * change: Rename 'Index' to 'Id' in pueue status
  * fix: Clippy issues
  * tests: Test non-existing group deletion
  * refactor: Use assert_success and assert_failure in tests
  * tests: Group addition and removal
  * tests: Task removal
  * tests: Clean command
  * tests: Wait for unix socket instead of PID
  * update: Use pueue-lib's new TaskSelection enum
  * update: Use pueue-libs new GroupMessage enum
  * refactor: Restructure callback templating code
  * feature: Multi-spawn tasks per loop
  * docs: Add infos about TaskHandler properties
  * fix: Remove println from windows code
  * tests: Edit and pause
  * update: Dependencies
  * feature: Support client.restart_in_place default config
  * (cargo-release) version 1.0.0-rc.3
  * docs: Add missing changelog entry
  * feature: Add date to start/end on pueue status
  * tests: Enqueued and delayed tasks
  * update: Use pueue v0.16
  * update: Use pueue-lib v0.15
  * update: systemd pueued.service util files
  * fix: clippy and fmt condition in CI
  * fix: Longer test wait for potato CI
  * fix: Increase shutdown wait timeout in tests
  * fix: Clippy issues
  * fix: Don't compile test helper on non-linux
  * tests: State restore logic
  * fix: Daemon no longer paused after restart
  * (cargo-release) version 1.0.0-rc.2
  * refactor: Restructure tests for better platform isolation
  * bug: Fix unix import in tests for windows
  * bug: Only run shutdown test on unix
  * refactor: Simplify shutdown code
  * fix: Don't reset on shutdown
  * maintenance: Update dependencies
  * bug: Fix cli parameter conflict name
  * Bump dependencies
  * feat: --failed-in-group flag for restart
  * Move signal/panic initialization to its own function
  * Speed up test runs
  * Changelog and Readme updates
  * Adjust changelog
  * (cargo-release) version 1.0.0-rc.1
  * Update to pueue-lib 0.13, switch to v1.0
  * Use normal error handling, since the async stdout big has been fuxed
  * Update dependencies
  * Parameterize tests and allow multithreaded integration testing
  * Better start test and kill tests
  * Early mutex lock in spawn_new
  * Add tests for starting/continuing tasks and fix deadlock
  * Start daemon, if old pid no longer exists
  * Longer timeout for flaky windows process tests
  * Only run tests on linux
  * Update Changelogs
  * Add test wait functions and use tokio in tests
  * Only use needed tokio features
  * Simplify some things
  * Use tokio runtime
  * Restructure test helper/fixtures
  * Use results for test error handling
  * Use crossbeam channel with timeout in taskhandler
  * Tests for shutdown and simple task adding
  * More sleeps
  * Test CTRL-C/Sigterm daemon shutdown
  * Refactor message_handler kill if-else logic
  * Add pid file for daemon
  * Move more daemon setup logic from lib.rs to main.rs
  * Test helper for settings and tempdir
  * Use pretty_assertions
  * Add get test config helper
  * Split daemon in bin and lib
  * Refactor usage of tempdir in tests
  * Fix #208
  * Fix signal handling logic for fatal unix signals
  * fix handling children processes for shell under linux
  * Fix path in readme installation instruction
  * Pueue signal subcommand and state/error handling
  * Report deserialization errors to the client
  * Dependencies and new pueue-lib error handling
  * Fix daemon clean tests
  * Split TaskHandler monster file
  * Major error handling and TaskHandler refactoring.
  * Graceful shutdown on IO errors
  * New pueue-lib updates
  * Adjust tests to use temporary directory as pueue_directory
  * Edit changelog
  * Don't send environment variables in log json
  * Better pueue-lib error handling
  * Implement json log output
  * Restructure display/log and add some comments
  * Daemon version check during handshake
  * Tests for other targets
  * Add ios-aarch64 target release
  * Change macos target to apple target
  * client: Refactor remote log decompression code
  * Update dependencies
  * Use new callback_log_lines option
  * Pass last 10 lines of stdout/stderr to callback templating
  * Fix clippy issue
  * Switch to pueue-lib master for development
  * Add OS and FS stuff to gitignore
  * Use getter methods which actually expand tilde
  * Handle dependency management race condition
  * Update pueue -h text in Readme
  * (cargo-release) start next development iteration 0.12.3-alpha.0
  * (cargo-release) version 0.12.2
  * Update changelog
  * Remove unnecessary return
  * Split status logic for single or all groups
  * Update dependencies
  * Refactor linux kill_child code
  * WIP testing with pueue-lib 0.13
  * improve Windows support
  * Remove task logs on 'pueue remove'
  * Remove warning vor v0.10
  * (cargo-release) start next development iteration 0.12.2-alpha.0
  * (cargo-release) version 0.12.1
  * Update dependencies
  * Set release date for 0.12.1 and add new changelog entry
  * Change status of default group with empty queue on 'status'
  * Update dependency id's on switch
  * Fix some typos in docstrings
  * Add next version to CHANGELOG.md
  * docs: Fix typos and rework linux process handling docstrings
  * Set default thread count to 4
  * Update dependencies
  * Dependency bumps
  * Update bug report template
  * Fix issue template type
  * Update bug report template
  * Remove aur badage
  * Proofreading
  * docs: Add links to Architecture.md
  * ARCHITECTURE.md
  * Readme: Similar projects formatting
  * Readme and a little doc adjustment
  * Fix weird duplicate upload github action bug for arm release
  * (cargo-release) start next development iteration 0.12.1-alpha.0
  * (cargo-release) version 0.12.0
  * Fix readme path for v0.12.0
  * Change changelog for v0.12.0
  * Update the changelog
  * client: add support dark colors via settings file (dark_mode variable)
  * Adjust readme
  * Add --all-failed to restart and fix restart options
  * Split pueue-lib in a stand-alone repository
  * Update dependencies
  * (cargo-release) start next development iteration 0.11.3-alpha.0
  * (cargo-release) version 0.11.2
  * Switch from users crate to whoami
  * LICENSE
  * option docstrings cleanup
  * Use 127.0.0.1 instead of localhost
  * Remove unnecessary get_column_mut in log logic
  * Improve pueue log output
  * Changelog
  * (cargo-release) start next development iteration 0.11.2-alpha.0
  * (cargo-release) version 0.11.1
  * Prepare cargo-release for version 0.11.1
  * (cargo-release) version 0.11.1
* Sun Jan  2 2022 pousaduarte@gmail.com
- Update to version 0.11.0:
  * 
* Sun Nov 14 2021 pousaduarte@gmail.com
- Update to version 1.0.4:
  * (cargo-release) version 1.0.4
  * fix: Panic when switching task with itself.
  * fix: Some links to new main branch
  * ops: rename master to main
  * (cargo-release) start next development iteration 1.0.4-alpha.0
* Fri Sep 17 2021 pousaduarte@gmail.com
- Update to version 1.0.3:
  * (cargo-release) version 1.0.3
  * fix: Clippy issue
  * update: Pueue-lib v0.18.1
  * (cargo-release) start next development iteration 1.0.3-alpha.0
  * (cargo-release) version 1.0.2
  * fix: Load updated configs on daemon restart
  * test: Ensure settings are read on restore
  * feature: Add --working-directory to pueue add
  * (cargo-release) start next development iteration 1.0.2-alpha.0
* Sun Aug 29 2021 pousaduarte@gmail.com
- Update to version 1.0.1:
  * (cargo-release) version 1.0.1
  * docs: Update changelog
  * fix: Pin clap to exact beta version
  * docs: Require --locked parameter on cargo install
  * fix: Incremental wait logic for windows process tests
  * update: Various dependencies
  * update: Clap beta.4
  * docs: Require --locked parameter on cargo install
  * (cargo-release) start next development iteration 1.0.1-alpha.0
  * (cargo-release) version 1.0.0
  * docs: Update and proofread changelog
  * update: Bump ctrlc to 3.2.0
  * update: Replace deprecated tempdir with tempfile
  * update: Comfy-table 4.1
  * fix: Flakiness in worker pool tests
  * fix: Shutting down too fast
  * refactor: Cleanup test code
  * tests: Restarting tasks in-place
  * change: Return failure when no tasks are affected by action
  * tests: Parallelism with multiple groups
  * docs: Better remove test docs
  * refactor: Cleanup test code for stashed tasks
  * tests: Test special task add modes
  * fix: Flaky group tests due to new async group removal logic
  * fix: Remove unnecessary println calls
  * (cargo-release) version 1.0.0-rc.4
  * doc: Update Architecture.md
  * fix: Flaky tests due to new async group handling
  * refactor: Consistent naming conventions
  * fix: Clippy issues
  * tests: Improve group tests
  * feature: Dynamic worker pool creation/removal
  * change: Prevent group removal while it has tasks.
  * refactor: Move group addition/removal to TaskHandler
  * tests: Ensure worker variable injection into task environment
  * tests: Correct worker id re-usage
  * tests: Single worker variables
  * feature: Implement datastructure for worker pools
  * change: Only show exitcode on failure
  * change: Rename 'Index' to 'Id' in pueue status
  * fix: Clippy issues
  * tests: Test non-existing group deletion
  * refactor: Use assert_success and assert_failure in tests
  * tests: Group addition and removal
  * tests: Task removal
  * tests: Clean command
  * tests: Wait for unix socket instead of PID
  * update: Use pueue-lib's new TaskSelection enum
  * update: Use pueue-libs new GroupMessage enum
  * refactor: Restructure callback templating code
  * feature: Multi-spawn tasks per loop
  * docs: Add infos about TaskHandler properties
  * fix: Remove println from windows code
  * tests: Edit and pause
  * update: Dependencies
  * feature: Support client.restart_in_place default config
  * (cargo-release) version 1.0.0-rc.3
  * docs: Add missing changelog entry
  * feature: Add date to start/end on pueue status
  * tests: Enqueued and delayed tasks
  * update: Use pueue v0.16
  * update: Use pueue-lib v0.15
  * update: systemd pueued.service util files
  * fix: clippy and fmt condition in CI
  * fix: Longer test wait for potato CI
  * fix: Increase shutdown wait timeout in tests
  * fix: Clippy issues
  * fix: Don't compile test helper on non-linux
  * tests: State restore logic
  * fix: Daemon no longer paused after restart
  * (cargo-release) version 1.0.0-rc.2
  * refactor: Restructure tests for better platform isolation
  * bug: Fix unix import in tests for windows
  * bug: Only run shutdown test on unix
  * refactor: Simplify shutdown code
  * fix: Don't reset on shutdown
  * maintenance: Update dependencies
  * bug: Fix cli parameter conflict name
  * Bump dependencies
  * feat: --failed-in-group flag for restart
  * Move signal/panic initialization to its own function
  * Speed up test runs
  * Changelog and Readme updates
  * Adjust changelog
  * (cargo-release) version 1.0.0-rc.1
  * Update to pueue-lib 0.13, switch to v1.0
  * Use normal error handling, since the async stdout big has been fuxed
  * Update dependencies
  * Parameterize tests and allow multithreaded integration testing
  * Better start test and kill tests
  * Early mutex lock in spawn_new
  * Add tests for starting/continuing tasks and fix deadlock
  * Start daemon, if old pid no longer exists
  * Longer timeout for flaky windows process tests
  * Only run tests on linux
  * Update Changelogs
  * Add test wait functions and use tokio in tests
  * Only use needed tokio features
  * Simplify some things
  * Use tokio runtime
  * Restructure test helper/fixtures
  * Use results for test error handling
  * Use crossbeam channel with timeout in taskhandler
  * Tests for shutdown and simple task adding
  * More sleeps
  * Test CTRL-C/Sigterm daemon shutdown
  * Refactor message_handler kill if-else logic
  * Add pid file for daemon
  * Move more daemon setup logic from lib.rs to main.rs
  * Test helper for settings and tempdir
  * Use pretty_assertions
  * Add get test config helper
  * Split daemon in bin and lib
  * Refactor usage of tempdir in tests
  * Fix #208
  * Fix signal handling logic for fatal unix signals
  * fix handling children processes for shell under linux
  * Fix path in readme installation instruction
  * Pueue signal subcommand and state/error handling
  * Report deserialization errors to the client
  * Dependencies and new pueue-lib error handling
  * Fix daemon clean tests
  * Split TaskHandler monster file
  * Major error handling and TaskHandler refactoring.
  * Graceful shutdown on IO errors
  * New pueue-lib updates
  * Adjust tests to use temporary directory as pueue_directory
  * Edit changelog
  * Don't send environment variables in log json
  * Better pueue-lib error handling
  * Implement json log output
  * Restructure display/log and add some comments
  * Daemon version check during handshake
  * Tests for other targets
  * Add ios-aarch64 target release
  * Change macos target to apple target
  * client: Refactor remote log decompression code
  * Update dependencies
  * Use new callback_log_lines option
  * Pass last 10 lines of stdout/stderr to callback templating
  * Fix clippy issue
  * Switch to pueue-lib master for development
  * Add OS and FS stuff to gitignore
  * Use getter methods which actually expand tilde
  * Handle dependency management race condition
  * Update pueue -h text in Readme
  * (cargo-release) start next development iteration 0.12.3-alpha.0
* Sun May 16 2021 pousaduarte@gmail.com
- Update to version 0.12.2:
  * (cargo-release) version 0.12.2
  * Update changelog
  * Remove unnecessary return
  * Split status logic for single or all groups
  * Update dependencies
  * Refactor linux kill_child code
  * WIP testing with pueue-lib 0.13
  * improve Windows support
  * Remove task logs on 'pueue remove'
  * Remove warning vor v0.10
  * (cargo-release) start next development iteration 0.12.2-alpha.0
  * (cargo-release) version 0.12.1
  * Update dependencies
  * Set release date for 0.12.1 and add new changelog entry
  * Change status of default group with empty queue on 'status'
  * Update dependency id's on switch
  * Fix some typos in docstrings
  * Add next version to CHANGELOG.md
  * docs: Fix typos and rework linux process handling docstrings
  * Set default thread count to 4
  * Update dependencies
  * Dependency bumps
  * Update bug report template
  * Fix issue template type
  * Update bug report template
  * Remove aur badage
  * Proofreading
  * docs: Add links to Architecture.md
  * ARCHITECTURE.md
  * Readme: Similar projects formatting
  * Readme and a little doc adjustment
* Thu Feb 11 2021 pousaduarte@gmail.com
- Update to version 0.12.0:
  * Fix weird duplicate upload github action bug for arm release
  * (cargo-release) start next development iteration 0.12.1-alpha.0
  * (cargo-release) version 0.12.0
  * Fix readme path for v0.12.0
  * Change changelog for v0.12.0
  * Update the changelog
  * client: add support dark colors via settings file (dark_mode variable)
  * Adjust readme
  * Add --all-failed to restart and fix restart options
  * Split pueue-lib in a stand-alone repository
  * Update dependencies
  * (cargo-release) start next development iteration 0.11.3-alpha.0
  * (cargo-release) version 0.11.2
  * Switch from users crate to whoami
  * LICENSE
  * option docstrings cleanup
  * Use 127.0.0.1 instead of localhost
  * Remove unnecessary get_column_mut in log logic
  * Improve pueue log output
  * Changelog
  * (cargo-release) start next development iteration 0.11.2-alpha.0
* Sun Jan 24 2021 pousaduarte@gmail.com
- Update to version pueue0.11.1:
  * (cargo-release) version 0.11.1
  * Prepare cargo-release for version 0.11.1
  * (cargo-release) version 0.11.1
  * Fix packaging for new release tags
  * Next development cycle for pueue-lib with 0.11.1-alpha.0
  * (cargo-release) start next development iteration 0.11.1-alpha.0
  * (cargo-release) version 0.11.0
  * Use top-level readme for pueue crate
  * Set pueue-lib import, set next iteration cycle to patch
  * (cargo-release) start next development iteration 0.11.1-alpha.0
* Mon Jan 18 2021 pousaduarte@gmail.com
- Update to version pueuelib0.11.0:
  * (cargo-release) version 0.11.0
  * Remove 6th keyword from pueue-lib
  * Add pueue-lib readme
  * Set release date in Changelog
  * Move build.rs to pueue and remove unneeded dependencies
  * Use workspaces
  * Better log output styling for task info
  * Fix clippy issues
  * Add new logic to limit remote log output
  * Fix missing newline between tasks in log output
  * Add new logic to limit local log output
  * Restructure client display code
  * Add successful-only flag to clean
  * Update dependencies
  * Handle directories passed for config files
  * (cargo-release) start next development iteration 0.10.3-alpha.0
* Thu Dec 31 2020 pousaduarte@gmail.com
- Update to version 0.10.2:
  * (cargo-release) version 0.10.2
  * Prevent removal of tasks with active dependants
  * (cargo-release) start next development iteration 0.10.2-alpha.0
  * (cargo-release) version 0.10.1
  * Fix panic on 'status' when only having tasks in non-default groups
  * Remove donations
  * (cargo-release) start next development iteration 0.10.1-alpha.0
  * (cargo-release) version 0.10.0
  * Run ci on ci file changes
  * Drop non-stable support
  * Update required rust version to 1.48
  * Update dependencies
  * Fix clippy issue
  * Adjust wait command parameter handling
  * Contribution guide formatting
  * Streamline and proofread pueue cli help
  * Fix kill task_id cli behavior
  * Better IO error handling
  * Fix contribution guide link in README
  * v0.10.0
  * Update dependencies
  * Move missing Win/Mac features from readme to issues
  * Add option to automatically escape parameters strings
  * Set proper file permissions for sensitive files
  * Use unix sockets by default on unix systems
  * Changelog wording
  * Add task labels
  * Some more code cleanup
  * Some more cleanup and fixing minor issues
  * Make the default group an actual group
  * Better group status handling
  * Exit client with non-zero on failure
  * Move platform specific network code into network submodule
  * Better error message when failing to listen
  * Better rand secret generation
  * Better setting pass-through behavior
  * Completley remove unix sockets from windows and add host
  * Certificate generation
  * Counter brute-force and timing attacks
  * Move daemon network related code into own module
  * Move network related stuff into its own module
  * Update windows tcp code
  * Fix clippy issues
  * Fix tests
  * Put shared secret into file and use PathBuf in settings
  * Remove client certificate pinning again
  * Comments and minor code restructurings
  * Better daemon fork code flow
  * Remove some unnecessary complex commandline flags
  * Client authentication via tls
  * Basic tls is running
  * Rename socket variables to stream
  * Rename types from Socket to Stream
  * Better tls code error handling
  * WIP: Fixes and configuration
  * Client-side tls code
  * Server side tls code
  * Add option to only return task_id on add
  * Use repology for pkgstatus on distros
  * (cargo-release) start next development iteration 0.9.1-alpha.0
* Tue Dec 15 2020 pousaduarte@gmail.com
- Update to version 0.9.0:
  * (cargo-release) version 0.9.0
  * Set v0.9.0 date
  * Fix some bugs
  * Update dependencies
  * Remove clippy issue
  * Fix pause_on_failure for groups
  * Don't update tasks with failed dependencies on paused groups
  * Add --in-place flag to restart
  * Cleanup wrong comments in wait
  * Add client CLI conflicts and remove unnecessary groups
  * Update changelog
  * Only run linter on stable
  * Make wait log output pretty
  * Edit original commands
  * First draft for 'wait' subcommand
  * Update dependencies
  * Update TaskResult and TaskStatus docs
  * Fixes #143
  * (cargo-release) start next development iteration 0.8.3-alpha.0
* Sun Nov 29 2020 pousaduarte@gmail.com
- Update to version 0.8.2:
  * (cargo-release) version 0.8.2
  * Set changelog v0.8.2 date
  * Only run CI when changing rust stuff
  * Update changelog
  * Remove unnecessary Result<> in check_new
  * Update comment
  * Handle state on handle_complex_command. If there are no running tasks, or the user confirmed the removal of these manually handle reset with handle_simple_command.
  * Add new flag `force` (short and long) to reset subcommand.
  * Add some client docs
  * Fix v1.49 clippy issues
  * Ensure backward compatibility from now on
  * Add exit_code as callback parameter. Resolves #138
  * Require Rust v1.42
  * Readme typo
  * Changelog
  * Minor code cleanup
  * Comments and better function name
  * Adjust some comments
  * Move unit tests from tests directory into respective module
  * Remove test helper scripts
  * Cargo fmt
  * Fix shell completion script generation
  * Fix shell completions
  * Rename Opt to CliArguments
  * Use Clap v3.0.0-beta
  * (cargo-release) start next development iteration 0.8.2-alpha.0
* Thu Oct 29 2020 pousaduarte@gmail.com
- Update to version 0.8.1:
  * (cargo-release) version 0.8.1
  * Set changelog version date
  * Better logger init code
  * Rename config name
  * Update changelog
  * Option to limit row height in 'status'
  * Update dependencies
  * updated changelog to include time parameters to callback hooks
  * Enable zsh in build_completions
  * fix zsh completion hang
